@@ -330,6 +330,23 @@ class MachoAnalyzer:
             fastpath_funcptrs_to_selector_names[sym.address] = selector_name
         return fastpath_funcptrs_to_selector_names
 
+    def _get_objc_selector_stubs(self) -> Dict[VirtualMemoryPointer, str]:
+        # TODO(PT): Could this be in a segment other than __TEXT?
+        objc_stubs_section = self.binary.section_with_name("__objc_stubs", "__TEXT")
+        if not objc_stubs_section:
+            return {}
+
+        # Consider every named symbol within __objc_stubs to be a potential selector stub entry point
+        objc_selector_stubs = {}
+        selector_stub_prefix = "_objc_msgSend$"
+        for symbol_addr, symbol_name in self.exported_symbol_pointers_to_names.items():
+            if objc_stubs_section.address <= symbol_addr < objc_stubs_section.address + objc_stubs_section.size:
+                # Ignore symbols that don't follow the selector stubs format
+                if not symbol_name.startswith(selector_stub_prefix):
+                    continue
+                objc_selector_stubs[symbol_addr] = symbol_name[len(selector_stub_prefix) :]
+        return objc_selector_stubs
+
     def _build_xref_database(self) -> None:
         """Iterate all the code in the binary and populate the following DB tables:
         * function_calls
@@ -349,6 +366,12 @@ class MachoAnalyzer:
         if self._objc_msgSend_addr:
             objc_function_family.append(self._objc_msgSend_addr)
 
+        # SCAN-3535: For each function entry point, we'll need its file offset.
+        # When the function is in __TEXT this'll simply be (virt_addr - __TEXT.virt_base), but we've encountered
+        # cases in which functions are stored in a segment other than __TEXT.
+        boundaries_with_file_off = [
+            (tup, self.binary.file_offset_for_virtual_address(tup[0])) for tup in self.get_function_boundaries()
+        ]
         build_xref_database_fast(
             self,
             self.binary.path.as_posix(),
@@ -357,7 +380,8 @@ class MachoAnalyzer:
             self.binary.get_file_offset(),
             self._objc_msgSend_addr,
             objc_function_family,
-            list(self.get_function_boundaries()),
+            boundaries_with_file_off,
+            self._get_objc_selector_stubs(),
         )
 
         self._has_computed_xrefs = True
@@ -528,7 +552,7 @@ class MachoAnalyzer:
     def get_imps_for_sel(self, selector: str) -> List["ObjcFunctionAnalyzer"]:
         """Retrieve a list of the disassembled function data for every implementation of a provided selector
         Args:
-            selector: The selector name who's implementations should be found
+            selector: The selector name whose implementations should be found
 
         Returns:
             A list of ObjcFunctionAnalyzers corresponding to each found implementation of the provided selector.
@@ -670,16 +694,21 @@ class MachoAnalyzer:
     def get_cstrings(self) -> Set[str]:
         """Return the list of strings in the binary's __cstring section."""
         if not self.__cached_cstrings:
-            self.__cached_cstrings = self._strings_in_section("__cstring")
+            # We need to double-check what segment __cstring is in, as it might not be __TEXT
+            segment = "__TEXT"
+            cstring_section = self.binary.get_cstring_section()
+            if cstring_section:
+                segment = cstring_section.segment_name
+            self.__cached_cstrings = self._strings_in_section("__cstring", segment)
         return self.__cached_cstrings
 
     def _build_cstring_map(self) -> Dict[str, VirtualMemoryPointer]:
-        strings_section = self.binary.section_with_name("__cstring", "__TEXT")
-        if not strings_section:
+        cstring_section = self.binary.get_cstring_section()
+        if not cstring_section:
             return {}
 
-        strings_base = strings_section.address
-        strings_content = self.binary.get_bytes(strings_section.offset, strings_section.size)
+        strings_base = cstring_section.address
+        strings_content = self.binary.get_bytes(cstring_section.offset, cstring_section.size)
 
         string_to_stringrefs = {}
         # split into characters (string table is packed and each entry is terminated by a null character)
@@ -824,10 +853,10 @@ class MachoAnalyzer:
 
         self._db_handle.commit()
 
-    def _strings_in_section(self, section_name: str) -> Set[str]:
+    def _strings_in_section(self, section_name: str, segment_name: str = "__TEXT") -> Set[str]:
         """Fetch the list of strings located inside the provided section."""
         discovered_strings = set()
-        string_section = self.binary.section_with_name(section_name, "__TEXT")
+        string_section = self.binary.section_with_name(section_name, segment_name)
         if string_section:
             strings_content = self.binary.get_bytes(string_section.offset, string_section.size)
             transformed_strings = MachoStringTableHelper.transform_string_section(list(strings_content))
