@@ -1,4 +1,5 @@
 import functools
+import shlex
 from itertools import starmap
 from subprocess import check_output
 from typing import List, Optional
@@ -7,21 +8,21 @@ from capstone import CsInsn
 from strongarm_dataflow.dataflow import get_register_contents_at_instruction_fast
 from strongarm_dataflow.register_contents import RegisterContents, RegisterContentsType
 
-from strongarm.debug_util import DebugUtil
+from strongarm.logger import strongarm_logger
 from strongarm.macho import MachoBinary, ObjcClass, ObjcSelector, VirtualMemoryPointer
 
 from .objc_instruction import ObjcBranchInstruction, ObjcInstruction, ObjcUnconditionalBranchInstruction
 
+logger = strongarm_logger.getChild(__file__)
+
 
 def _is_mangled_cpp_symbol(symbol_name: str) -> bool:
-    """Return whether a symbol name appears to be a mangled C++ symbol.
-    """
+    """Return whether a symbol name appears to be a mangled C++ symbol."""
     return any(symbol_name.startswith(prefix) for prefix in ["_Z", "__Z", "___Z"])
 
 
 def _demangle_cpp_symbol(cpp_symbol: str) -> str:
-    """Call into c++filt to demangle the provided mangled C++ symbol name.
-    """
+    """Call into c++filt to demangle the provided mangled C++ symbol name."""
     if not _is_mangled_cpp_symbol(cpp_symbol):
         return cpp_symbol
 
@@ -42,7 +43,7 @@ def _demangle_cpp_symbol(cpp_symbol: str) -> str:
     # Try demangling multiple times, trimming a leading underscore each time until success (up to 3 times)
     for _ in range(3):
         # If demangling fails, allow the exception to propagate up. This can alert us to scanner issues.
-        demangled_symbol = check_output(f"c++filt -_ {cpp_symbol}", shell=True).decode().strip()
+        demangled_symbol = check_output(["c++filt", "-_", shlex.quote(cpp_symbol)]).decode().strip()
         # Was the symbol demangled?
         if demangled_symbol != cpp_symbol:
             if is_block:
@@ -114,8 +115,7 @@ class ObjcFunctionAnalyzer:
         self.basic_blocks = self._find_basic_blocks()
 
     def _get_instruction_index_of_address(self, address: VirtualMemoryPointer) -> Optional[int]:
-        """Return the index of an instruction with a provided address within the internal list of instructions
-        """
+        """Return the index of an instruction with a provided address within the internal list of instructions."""
         base_address = self.start_address
         offset = address - base_address
         index = int(offset / MachoBinary.BYTES_PER_INSTRUCTION)
@@ -124,8 +124,7 @@ class ObjcFunctionAnalyzer:
         return None
 
     def get_instruction_at_index(self, index: int) -> Optional[CsInsn]:
-        """Get the instruction at a given index within the function's code, wrapping in ObjcInstruction
-        """
+        """Get the instruction at a given index within the function's code, wrapping in ObjcInstruction."""
         if 0 <= index < len(self.instructions):
             return self.instructions[index]
         return None
@@ -148,15 +147,15 @@ class ObjcFunctionAnalyzer:
             output: string to output to debug log
         """
         if not len(self.instructions):
-            DebugUtil.log(self, f"func(stub) {output}")
+            logger.debug(self, f"func(stub) {output}")
         else:
             func_base = self.start_address
             instruction_address = func_base + (idx * MachoBinary.BYTES_PER_INSTRUCTION)
-            DebugUtil.log(self, f"func({hex(int(instruction_address))}) {output}")
+            logger.debug(self, f"func({hex(int(instruction_address))}) {output}")
 
     def get_symbol_name(self) -> str:
         """Return a objective-c class/method, c function, or sub_address-style string representing the name of
-            this block of code.
+        this block of code.
         """
         if self.method_info:
             return f"-[{self.method_info.objc_class.name} {self.method_info.objc_sel.name}]"
@@ -244,8 +243,7 @@ class ObjcFunctionAnalyzer:
 
     @property
     def call_targets(self) -> List[ObjcBranchInstruction]:
-        """Return the List of all branch instructions within the source function.
-        """
+        """Return the List of all branch instructions within the source function."""
         # Use cached list if available
         if self._call_targets is not None:
             return self._call_targets
@@ -287,7 +285,8 @@ class ObjcFunctionAnalyzer:
         return call_targets
 
     def get_local_branches(self) -> List[ObjcBranchInstruction]:
-        """Return all instructions in the analyzed function representing a branch to a destination within the function
+        """Return all instructions in the analyzed function representing a branch to a destination within
+        the source function.
         """
         local_branches = []
         for target in self.call_targets:
